cancel method

void cancel()

Cancels the ongoing operation associated with the _cancelToken.

This method triggers the cancellation of the request or task associated with the CancelToken. It is commonly used when the user wants to abort a request, for example, when they navigate away from a screen or if an operation is no longer required.

Example usage:

canceller.cancel();

Implementation

void cancel() {
  _cancelToken.cancel();
}