cancelToken property

CancelToken get cancelToken

A getter that allows access to the current _cancelToken.

This getter provides the CancelToken instance, which can be passed to Dio requests or used for checking the cancellation state of a particular operation.

Example usage:

final token = canceller.cancelToken;
dio.get('https://example.com', cancelToken: token);

Implementation

CancelToken get cancelToken => _cancelToken;