ImpakRetroFormData class

A utility class for converting a map of key-value pairs into a FormData object, which is used for making HTTP POST requests with multipart form data.

This class is particularly useful for handling form submissions that include files.

Constructors

ImpakRetroFormData([Map<String, dynamic> _data = const {}])
Constructor to initialize the _data map.

Properties

data Future<FormData>
A getter that asynchronously converts _data into a FormData object.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited