models/impak_retro_exceptions library

Classes

ImpakRetroException
A custom exception class to handle specific errors in the application.

Enums

ExceptionType
Enum representing various types of exceptions that can occur in the application.