ImpakRetroSuccess<T> class

Represents a successful response with typed data.

T is the type of data returned in the response.

Inheritance

Constructors

ImpakRetroSuccess({required int? statusCode, required T data})
Creates an ImpakRetroSuccess with the given statusCode and data.

Properties

asBody → T
no setterinherited
asError → dynamic
no setterinherited
data → T
The data returned in the successful response. // ignore: overridden_field
final
failure → dynamic
The error details associated with the response, if any.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isSuccessful bool
Returns true if the response is successful and contains data.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
The HTTP status code of the response, if applicable.
getter/setter pairinherited
success → T?
The data returned in the response, if available.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited