ImpakRetroFormData class
A utility class for converting a map of key-value pairs into a FormData object,
which is used for making HTTP POST requests with multipart form data.
This class is particularly useful for handling form submissions that include files.
Constructors
-
ImpakRetroFormData([Map<
String, dynamic> _data = const {}]) -
Constructor to initialize the
_datamap.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited