export/impak_http library
Re-exports selected Dio types so apps only depend on
impak_retro when writing Interceptors or ImpakRetroClientInterceptor subclasses.
Classes
- Dio
- Dio enables you to make HTTP requests easily.
- ErrorInterceptorHandler
- The handler for interceptors to handle error occurred during the request.
- Interceptor
- Interceptor helps to deal with RequestOptions, Response, and DioException during the lifecycle of a request before it reaches users.
- RequestInterceptorHandler
- The handler for interceptors to handle before the request has been sent.
- RequestOptions
-
The internal request option class that is the eventual result after
BaseOptionsandOptionsare composed. -
Response<
T> - The Response class contains the payload (could be transformed) that respond from the request, and other information of the response.
- ResponseInterceptorHandler
- The handler for interceptors to handle after respond.
Enums
- DioExceptionType
- The exception enumeration indicates what type of exception has happened during requests.
Exceptions / Errors
- DioException
- DioException describes the exception info when a request failed.