impak library
Classes
- Canceller
- A class that helps manage the cancellation of asynchronous operations, particularly network requests made using the Dio package.
- Dio
- Dio enables you to make HTTP requests easily.
- ErrorInterceptorHandler
- The handler for interceptors to handle error occurred during the request.
- ImpakResponse
- A specific implementation of ImpakRetroResponse for dynamic data.
- ImpakRetro
- A class that handles HTTP requests using the Dio package with customizable configurations.
- ImpakRetroClientInterceptor
- Dio Interceptor with explicit pre-request and post-response / post-error hooks for app code (access-token checks, refresh flows, global 401 handling, etc.).
- ImpakRetroClientInterceptorCallbacks
- Callback-driven ImpakRetroClientInterceptor when subclassing is not preferred.
- ImpakRetroException
- A custom exception class to handle specific errors in the application.
- ImpakRetroFailure
- Represents a response that indicates a failure without a valid result.
-
ImpakRetroResponse<
T> - A sealed base class representing a generic response.
-
ImpakRetroSuccess<
T> - Represents a successful response with typed data.
- Interceptor
- Interceptor helps to deal with RequestOptions, Response, and DioException during the lifecycle of a request before it reaches users.
- RequestInterceptorHandler
- The handler for interceptors to handle before the request has been sent.
- RequestOptions
-
The internal request option class that is the eventual result after
BaseOptionsandOptionsare composed. -
Response<
T> - The Response class contains the payload (could be transformed) that respond from the request, and other information of the response.
- ResponseInterceptorHandler
- The handler for interceptors to handle after respond.
Enums
- DioExceptionType
- The exception enumeration indicates what type of exception has happened during requests.
- ExceptionType
- Enum representing various types of exceptions that can occur in the application.
- RequestMethod
- Represents the different HTTP request methods supported by the application.
- TimeUnit
- Represents the units of time used for configuration, such as timeouts.
Typedefs
Exceptions / Errors
- DioException
- DioException describes the exception info when a request failed.