setAuthToken static method
Sets the authorization token for all requests.
This token will be used for all requests made by ImpakRetro unless another token is explicitly passed to a request.
Implementation
static void setAuthToken(String authToken) {
_authToken = authToken;
}