menu
impak_retro package
documentation
models/impak_retro_exceptions.dart
models/impak_retro_exceptions.dart
dark_mode
light_mode
models/impak_retro_exceptions
library
Classes
ImpakRetroException
A custom exception class to handle specific errors in the application.
Enums
ExceptionType
Enum representing various types of exceptions that can occur in the application.
impak_retro package
documentation
models/impak_retro_exceptions.dart
impak_retro
package
Libraries
config/canceller
config/config
config/impak_retro_form_data
config/request_methods
config/time_units
impak
impak_retro
models/impak_retro_exceptions
models/impak_retro_response
models/models
impak_retro_exceptions library