ImpakRetroException class
A custom exception class to handle specific errors in the application.
This class implements the Exception interface and provides additional information about the error through its type, message, and status code.
Constructors
- ImpakRetroException(ExceptionType type, {String? message, required int? statusCode})
-
Creates an ImpakRetroException with the specified
type,message, andstatusCode.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
A user-defined message that describes the exception.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int?
-
The HTTP status code associated with the exception, if applicable.
final
- type → ExceptionType
-
The type of exception, represented by the ExceptionType enum.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited