ImpakRetroFailure class
Represents a response that indicates a failure without a valid result.
This class is useful for scenarios where an operation fails but does not throw an exception.
- Inheritance
-
- Object
- ImpakRetroResponse<
Never> - ImpakRetroFailure
Constructors
- ImpakRetroFailure({required int? statusCode, required dynamic error})
-
Creates an ImpakRetroFailure with the given
statusCodeanderror.
Properties
- asBody → Never
-
no setterinherited
- asError → dynamic
-
no setterinherited
- error → dynamic
-
The error details associated with the failure.
final
- failure → dynamic
-
The error details associated with the response, if any.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSuccessful → bool
-
Returns
trueif the response is successful and contains data.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode ↔ int?
-
The HTTP status code of the response, if applicable.
getter/setter pairinherited
- success → Never
-
The data returned in the response, if available.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited