models/models library

Classes

ImpakResponse
A specific implementation of ImpakRetroResponse for dynamic data.
ImpakRetroException
A custom exception class to handle specific errors in the application.
ImpakRetroFailure
Represents a response that indicates a failure without a valid result.
ImpakRetroResponse<T>
A sealed base class representing a generic response.
ImpakRetroSuccess<T>
Represents a successful response with typed data.

Enums

ExceptionType
Enum representing various types of exceptions that can occur in the application.